// author: Yury Belyaev (ALMF EMBL)
//This macro calculates the coefficient of variation 
//(CV, ratio of standard deviation to mean) of the intensity 
//in the confocal image acquired in standardized conditions.  

var ImageList = newArray(nImages);

//Checks for opened windows 
function PopulateImageList(){ 
  if (nImages==0)
		exit("No images opened");
  	else {
		if (ImageList.length != nImages)
			ImageList = newArray(nImages);	
		for (i=1; i<=nImages; i++) {
        		selectImage(i);
        		ImageList[i-1]=getTitle();
     		}
  	}
}

macro "Detector CV" {
//Checks for opened windows 
	PopulateImageList();
// Read stack of two images
	Dialog.create("Detector CV");
	Dialog.addChoice("Select Image",ImageList);
	Dialog.show();
	image = Dialog.getChoice();
// Extract individual slices
	setBatchMode(true);
	selectImage(image);
	setSlice(1);
	run("Duplicate...", "title=1");
	selectImage(image);
	setSlice(2);
	run("Duplicate...", "title=2");
// Calculate mean intensity
	imageCalculator("Add create 32-bit", "1","2");
	getStatistics(area, mean, min, max, std, histogram);
	mean1=mean/2;
	run("Close"); 
// Calculate standard deviation
	imageCalculator("Subtract create 32-bit", "1","2");
	getStatistics(area, mean, min, max, std, histogram);
	std1=std/1.41;
	run("Close"); 
// Calculate coefficient of variation
	cv=100*std1/mean1;
// Close all used windows
	selectWindow("1"); 
	run("Close"); 
	selectWindow("2"); 
	run("Close"); 
	print(image, cv, "%");
	selectImage(image);
	run("Close");
	setBatchMode(true);	
}